<template>
  <a-card
    title=''
    :bordered='false'
  >
    <div class='table-page-search-wrapper'>
      <a-form
        layout='inline'
        @keyup.enter.native='searchQuery'
      >
        <a-row :gutter='24'>
          <a-col
            :xl='6'
            :lg='7'
            :md='8'
            :sm='24'
          >
            <a-form-item label='单据号'>
              <j-input
                placeholder='请输入单据号'
                v-model='queryParam.num'
              ></j-input>
            </a-form-item>
          </a-col>
          <a-col
            :xl='6'
            :lg='7'
            :md='8'
            :sm='24'
          >
            <span
              style='float: left;overflow: hidden;'
              class='table-page-search-submitButtons'
            >
              <a-button
                type='primary'
                @click='searchQuery'
                icon='search'
              >查询</a-button>
              <a-button
                type='primary'
                @click='searchReset'
                icon='reload'
                style='margin-left: 8px'
              >重置</a-button>
            </span>
          </a-col>
        </a-row>
      </a-form>
    </div>

    <div class='table-operator'>
      <a-button
        @click='handleAdd'
        type='primary'
        v-has="'sparePartCancellingStocks:add'"
        icon='plus'
      >新增
      </a-button>
      <a-button @click='handleSubmit' type='primary' icon='check' v-has="'sparePartCancellingStocks:submitAndCancel'"
                v-if="selectedRowKeys.length > 0  && (selectionRows[0].status ==='0'  || selectionRows[0].status==='3')">
        提交
      </a-button>
      <a-button v-if="selectedRowKeys.length > 0  && selectionRows[0].status==='1'"
                @click='handleRevocation' type='primary' icon='rollback'>撤回
      </a-button>
    </div>

    <div>


      <a-table
        ref='table'
        size='middle'
        bordered
        rowKey='id'
        :scroll="{ x: 'calc(1400px + 50%)', y: 900 }"
        :columns='columns'
        :dataSource='dataSource'
        :pagination='ipagination'
        :loading='loading'
        :rowSelection="{selectedRowKeys: selectedRowKeys, onChange: onSelectChange, type:'radio'}"
        :customRow='clickThenSelect'
        @change='handleTableChange'
      >

        <!--              <span
                        slot='action'
                        slot-scope='text, record'
                      >
                  <a v-if="record.status === '0' || record.status === '3'" @click='handleEdit(record)'>编辑</a>
                  <a v-if="record.status === '1'" @click='handleApprove(record)'>审批</a>

                  <a-divider v-if="record.status === '0' || record.status === '3'" type='vertical' />
                <a-dropdown v-if="record.status === '0' || record.status === '3'">
                                <a class='ant-dropdown-link'>更多 <a-icon type='down' /></a>
                                <a-menu slot='overlay'>
                                    <a-menu-item>
                                        <a-popconfirm title='确定删除吗?'
                                                      @confirm='() => handleDelete(record.id)'>
                                            <a>删除</a>
                                        </a-popconfirm>
                                    </a-menu-item>

                                </a-menu>
                            </a-dropdown>
                </span>-->
        <span
          slot='action'
          slot-scope='text, record'
        >
          <a v-if="record.status === '0' || record.status === '3'" @click='handleEdit(record)'  v-has="'sparePartCancellingStocks:edit'">编辑</a>
          <a v-if="record.status === '1'" @click='handleApprove(record)'>审批</a>
                <a-divider
                  v-if="record.status == '0' || record.status == '3' || record.status == '1'"
                  type='vertical'
                />
          <a-dropdown>
            <a class='ant-dropdown-link'>更多 <a-icon type='down' /></a>
            <a-menu slot='overlay'>
              <a-menu-item>
                <a @click='handleDetail(record)'>详情</a>
              </a-menu-item>
              <a-menu-item v-if="record.status == '0'||record.status == '3'"  v-has="'sparePartCancellingStocks:delete'">
                <a-popconfirm
                  title='确定删除吗?'
                  @confirm='() => handleDelete(record.id)'
                >
                  <a>删除</a>
                </a-popconfirm>
              </a-menu-item>
            </a-menu>
          </a-dropdown>
        </span>
      </a-table>
      <a-tabs
        type='card'
        defaultActiveKey='1'
      >
        <a-tab-pane
          tab='备件退库明细信息'
          key='1'
        >
          <div
            class='table-operator'
            style='margin:-16px'
          >
            <spare-part-cancelling-stocks-detail-list :sparePartCancellingId='sparePartCancellingId' />
          </div>
        </a-tab-pane>

      </a-tabs>
    </div>

    <spare-part-cancelling-stocks-modal
      ref='modalForm'
      @ok='modalFormOk'
    ></spare-part-cancelling-stocks-modal>
    <approvel-modal ref='approvalModalForm' @ok='approvalModalFormOk' @cancel='approvalModalFormOk'></approvel-modal>
  </a-card>
</template>

<script>

import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import { getAction, requestPut } from '@/api/manage'
import SparePartCancellingStocksDetailList
  from './modules/sparePartCancellingStocks/SparePartCancellingStocksDetailList'
import SparePartCancellingStocksModal from './modules/sparePartCancellingStocks/SparePartCancellingStocksModal'
import '@/assets/less/TableExpand.less'
import ApprovelModal from '@views/common/ApprovelModal'

export default {
  name: 'SparePartCancellingStocksList',
  mixins: [JeecgListMixin],
  components: {
    SparePartCancellingStocksDetailList,
    SparePartCancellingStocksModal,
    ApprovelModal
  },
  data() {
    return {
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 60,
          align: 'center',
          customRender: function(t, r, index) {
            return parseInt(index) + 1
          }
        },
        {
          title: '单据号',
          align: 'center',
          dataIndex: 'num'
        },
        /*  {
            title: '出库类型',
            align: 'center',
            dataIndex: 'type',
          },*/
        {
          title: '状态',
          align: 'center',
          dataIndex: 'status_dictText'
        },
        {
          title: '仓库',
          align: 'center',
          dataIndex: 'warehouseId_dictText'
        },
        {
          title: '领用部门',
          align: 'center',
          dataIndex: 'departId_dictText'
        },
        {
          title: '领用人',
          align: 'center',
          dataIndex: 'userId_dictText'
        },
        {
          title: '创建人',
          align: 'center',
          dataIndex: 'createBy'
        },
        {
          title: '创建日期',
          align: 'center',
          dataIndex: 'createTime'
        },
        {
          title: '更新人',
          align: 'center',
          dataIndex: 'updateBy'
        },
        {
          title: '更新日期',
          align: 'center',
          dataIndex: 'updateTime'
        },

        {
          title: '备注',
          align: 'center',
          dataIndex: 'remark'
        },
        {
          title: '操作',
          dataIndex: 'action',
          align: 'center',
          fixed: 'right',
          scopedSlots: { customRender: 'action' },
          width: 200
        }
      ],
      url: {
        list: '/spare/sparePartCancellingStocks/list',
        delete: '/spare/sparePartCancellingStocks/delete',
        deleteBatch: '/spare/sparePartCancellingStocks/deleteBatch',
        submit: '/spare/sparePartCancellingStocks/submit',
        revocation: '/spare/sparePartCancellingStocks/revocation',
        reject: 'spare/sparePartCancellingStocks/reject',
        approval: 'spare/sparePartCancellingStocks/approval'
      },
      /* 分页参数 */
      ipagination: {
        current: 1,
        pageSize: 5,
        pageSizeOptions: ['5', '10', '50'],
        showTotal: (total, range) => {
          return range[0] + '-' + range[1] + ' 共' + total + '条'
        },
        showQuickJumper: true,
        showSizeChanger: true,
        total: 0
      },
      sparePartCancellingId: '-1'
    }
  },
  mounted() {
    this.$bus.$on('outGroundSuccess', (data) => {
      this.loadData()
    })
  },
  methods: {
    clickThenSelect(record) {
      return {
        on: {
          click: () => {
            this.onSelectChange(record.id.split(','), [record])
          }
        }
      }
    },
    onClearSelected() {
      this.selectedRowKeys = []
      this.selectionRows = []
      this.sparePartCancellingId = '-1'
    },
    onSelectChange(selectedRowKeys, selectionRows) {
      if (selectedRowKeys.length == 1) {
        this.sparePartCancellingId = selectionRows[0]['id']
      } else {
        this.sparePartCancellingId = '-1'
      }
      this.selectedRowKeys = selectedRowKeys
      this.selectionRows = selectionRows
    },


    handleApprove: function(record) {
      let reject, approval
      reject = this.url.reject
      approval = this.url.approval
      this.$refs.approvalModalForm.showModals(record, reject, approval)
      this.$refs.approvalModalForm.title = '审批'
      this.$refs.approvalModalForm.disableSubmit = false

    },
    approvalModalFormOk() {
      // 通过/驳回时，重载列表
      this.loadData()
      //清空列表选中
      this.onClearSelected()
    },
    loadData(arg) {
      if (!this.url.list) {
        this.$message.error('请设置url.list属性!')
        return
      }
      //加载数据 若传入参数1则加载第一页的内容
      if (arg === 1) {
        this.ipagination.current = 1
      }
      this.onClearSelected()
      var params = this.getQueryParams()//查询条件
      this.loading = true
      getAction(this.url.list, params).then((res) => {
        if (res.success) {
          this.dataSource = res.result.records
          this.ipagination.total = res.result.total
        }
        if (res.code === 510) {
          this.$message.warning(res.message)
        }
        this.loading = false
      })
    },
    searchReset() {
      this.sparePartCancellingId = '-1'
      this.queryParam = {}
      this.loadData(1)
    }
  }

}
</script>
<style scoped>
@import '~@assets/less/common.less';

.table-operator .ant-btn {
  margin: 10px 8px 8px 10px;
}
</style>